/// <reference path="fourslash.ts" />

//// /**/declare function

goTo.marker();
//verify there is no empty navigation item.
verify.navigationItemsListCount(0, "")
